Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Notifier ¶
type Notifier interface {
// Signal triggers the notifier, indicating an event has occurred.
Signal()
// Hold returns a channel that is closed when Signal is called, allowing callers to wait for a signal.
Hold() <-chan struct{}
}
Notifier interface defines the methods for signaling and waiting on notifications.
func NewNotifier ¶ added in v0.2.0
func NewNotifier() Notifier
func NewNotifierWithCancel ¶ added in v0.2.0
func NewNotifierWithCancel(parent context.Context) (Notifier, context.CancelFunc)
Click to show internal directories.
Click to hide internal directories.